==> devextreme-23.1.9.tgz: package/bundles/__internal/grids/tree_list/m_validating.js <==
/**
 * DevExtreme (bundles/__internal/grids/tree_list/m_validating.js)
 * Version: 23.1.9
 * Build date: Mon Mar 11 2024
 *
 * Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
var _m_validating = require("../../grids/grid_core/validating/m_validating");
var _m_core = _interopRequireDefault(require("./m_core"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var editingControllerExtender = function(Base) {
    return function(_validatingModule$ext) {
        _inheritsLoose(TreeListEditingControllerExtender, _validatingModule$ext);

        function TreeListEditingControllerExtender() {
            return _validatingModule$ext.apply(this, arguments) || this
        }
        var _proto = TreeListEditingControllerExtender.prototype;
        _proto.processDataItem = function(item) {
            _validatingModule$ext.prototype.processDataItemTreeListHack.apply(this, arguments)
        };
        _proto.processItems = function(items, e) {
            return _validatingModule$ext.prototype.processItemsTreeListHack.apply(this, arguments)
        };
        return TreeListEditingControllerExtender
    }(_m_validating.validatingModule.extenders.controllers.editing(Base))
};
_m_core.default.registerModule("validating", {
    defaultOptions: _m_validating.validatingModule.defaultOptions,
    controllers: _m_validating.validatingModule.controllers,
    extenders: {
        controllers: {
            editing: editingControllerExtender,
            editorFactory: _m_validating.validatingModule.extenders.controllers.editorFactory
        },
        views: _m_validating.validatingModule.extenders.views
    }
});

==> devextreme-23.2.5.tgz: package/bundles/__internal/grids/tree_list/m_validating.js <==
/**
 * DevExtreme (bundles/__internal/grids/tree_list/m_validating.js)
 * Version: 23.2.5
 * Build date: Mon Mar 11 2024
 *
 * Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
var _m_validating = require("../../grids/grid_core/validating/m_validating");
var _m_core = _interopRequireDefault(require("./m_core"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
const editingControllerExtender = Base => function(_validatingModule$ext) {
    _inheritsLoose(TreeListEditingControllerExtender, _validatingModule$ext);

    function TreeListEditingControllerExtender() {
        return _validatingModule$ext.apply(this, arguments) || this
    }
    var _proto = TreeListEditingControllerExtender.prototype;
    _proto.processDataItem = function(item) {
        _validatingModule$ext.prototype.processDataItemTreeListHack.apply(this, arguments)
    };
    _proto.processItems = function(items, e) {
        return _validatingModule$ext.prototype.processItemsTreeListHack.apply(this, arguments)
    };
    return TreeListEditingControllerExtender
}(_m_validating.validatingModule.extenders.controllers.editing(Base));
_m_core.default.registerModule("validating", {
    defaultOptions: _m_validating.validatingModule.defaultOptions,
    controllers: _m_validating.validatingModule.controllers,
    extenders: {
        controllers: {
            editing: editingControllerExtender,
            editorFactory: _m_validating.validatingModule.extenders.controllers.editorFactory
        },
        views: _m_validating.validatingModule.extenders.views
    }
});
